/*
 * (c) Copyright 2012 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.platform.mongodb;

import static org.databene.benerator.engine.DescriptorConstants.ATT_ENVIRONMENT;
import static org.databene.benerator.engine.DescriptorConstants.ATT_ID;
import static org.databene.benerator.engine.DescriptorConstants.ATT_ON_ERROR;
import static org.databene.benerator.engine.parser.xml.DescriptorParserUtil.parseScriptableStringAttribute;

import org.databene.benerator.engine.BeneratorRootStatement;
import org.databene.benerator.engine.Statement;
import org.databene.benerator.engine.parser.xml.AbstractBeneratorDescriptorParser;
import org.databene.benerator.engine.parser.xml.BeneratorParseContext;
import org.databene.benerator.engine.statement.IfStatement;
import org.databene.benerator.engine.statement.WhileStatement;
import org.databene.commons.CollectionUtil;
import org.databene.commons.ConfigurationError;
import org.databene.commons.ErrorHandler;
import org.databene.script.Expression;
import org.w3c.dom.Element;

/**
 * TODO Document class.<br/><br/>
 * Created: 29.01.2012 13:53:17
 * @since 0.7.5
 * @author Volker Bergmann
 */
public class MongoDBParser extends AbstractBeneratorDescriptorParser {
	
    static final String EL_MONGODB = "mongodb";

    public MongoDBParser() {
	    super(EL_MONGODB, 
	    		CollectionUtil.toSet(ATT_ID), 
	    		CollectionUtil.toSet(ATT_ENVIRONMENT, ATT_ON_ERROR),
	    		BeneratorRootStatement.class, IfStatement.class, WhileStatement.class);
    }

	@Override
	public MongoDBStatement doParse(Element element, Statement[] parentPath, BeneratorParseContext context) {
		String id = element.getAttribute("id");
        Expression<String> envEx = parseScriptableStringAttribute(ATT_ENVIRONMENT, element);
        if (envEx == null)
        	throw new ConfigurationError("no environment specified in <" + EL_MONGODB + "> element");
		Expression<ErrorHandler> errHandlerEx = parseOnErrorAttribute(element, EL_MONGODB);
		return new MongoDBStatement(id, envEx, errHandlerEx);
    }

}
