/*
 * (c) Copyright 2012 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.platform.mongodb;

import org.databene.commons.ConfigurationError;
import org.databene.commons.StringUtil;
import org.databene.jdbacl.DBUtil;
import org.databene.jdbacl.JDBCConnectData;
import org.databene.model.data.DataModel;

/**
 * TODO Document class.<br/><br/>
 * Created: 11.02.2012 07:12:40
 * @since TODO version
 * @author Volker Bergmann
 */
public class MongoUtil {

	public static MongoDB createMongoDBForEnvironment(String environment, String id, DataModel dataModel) {
		MongoDB mongoDB = new MongoDB(id, dataModel);
		JDBCConnectData connectData = DBUtil.getConnectData(environment);
		if (StringUtil.isEmpty(connectData.url))
			throw new ConfigurationError("No URL defined for environment " + environment);
		String[] urlTokens = StringUtil.splitOnLastSeparator(connectData.url, ':');
		mongoDB.setHost(urlTokens[0]);
		if (urlTokens.length > 1)
			mongoDB.setPort(Integer.parseInt(urlTokens[1]));
		mongoDB.setUser(connectData.user);
		mongoDB.setPassword(connectData.password);
		if (StringUtil.isEmpty(connectData.catalog))
			throw new ConfigurationError("No catalog configured for environment '" + environment + "'");
		mongoDB.setDatabase(connectData.catalog);
		return mongoDB;
	}

}
